Enum subprocess::ExitStatus [−][src]
Exit status of a process.
Variants
Exited(u32)The process exited with the specified exit code.
Note that the exit code is limited to a much smaller range on most platforms.
Signaled(u8)The process exited due to a signal with the specified number.
This variant is never created on Windows, where signals of Unix kind do not exist.
Other(i32)The process exit status cannot be described by the preceding two variants.
This should not occur in normal operation.
UndeterminedIt is known that the process has completed, but its exit status is unavailable.
This should not occur in normal operation, but if possible if
for example some foreign code calls waitpid() on the PID of
the child process.
Methods
impl ExitStatus[src]
impl ExitStatusTrait Implementations
impl Debug for ExitStatus[src]
impl Debug for ExitStatusfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Eq for ExitStatus[src]
impl Eq for ExitStatusimpl PartialEq for ExitStatus[src]
impl PartialEq for ExitStatusfn eq(&self, other: &ExitStatus) -> bool[src]
fn eq(&self, other: &ExitStatus) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ExitStatus) -> bool[src]
fn ne(&self, other: &ExitStatus) -> boolThis method tests for !=.
impl Copy for ExitStatus[src]
impl Copy for ExitStatusimpl Clone for ExitStatus[src]
impl Clone for ExitStatusfn clone(&self) -> ExitStatus[src]
fn clone(&self) -> ExitStatusReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more