[−][src]Type Definition subprocess::Result
type Result<T> = Result<T, PopenError>;
Result returned by calls in the subprocess crate in places where
::std::io::Result does not suffice.
type Result<T> = Result<T, PopenError>;
Result returned by calls in the subprocess crate in places where
::std::io::Result does not suffice.